pub enum AnyRenderBodyContext {
Html(HtmlRenderContext<ResponseWriter>),
Json(JsonBodyRenderer<ResponseWriter>),
Csv(CsvBodyRenderer),
}Expand description
Can receive rows, and write them in a given format to an io::Write
Variants
Html(HtmlRenderContext<ResponseWriter>)
Json(JsonBodyRenderer<ResponseWriter>)
Csv(CsvBodyRenderer)
Implementations
Sourceimpl AnyRenderBodyContext
Dummy impl to dispatch method calls to the underlying renderer
impl AnyRenderBodyContext
Dummy impl to dispatch method calls to the underlying renderer