Module execute_queries

Structs

StatementWithParams

Functions

stop_at_first_error
Transforms a stream of database items to stop processing after encountering the first error. The error item itself is still emitted before stopping.
stream_query_results_boxed
This function is used to create a pinned boxed stream of query results. This allows recursive calls.
stream_query_results_with_conn

Type Aliases

DbConn