pub struct OidcState {
pub config: OidcConfig,
/* private fields */
}Fields
config: OidcConfigImplementations
Sourceimpl OidcState
impl OidcState
pub async fn new(oidc_cfg: OidcConfig, app_config: AppConfig) -> Result<Self>
Sourcepub async fn refresh_if_expired(&self, service_request: &ServiceRequest)
pub async fn refresh_if_expired(&self, service_request: &ServiceRequest)
Refreshes the OIDC client from the provider metadata URL if it has expired. Most providers update their signing keys periodically.
Sourcepub async fn refresh_on_error(&self, service_request: &ServiceRequest)
pub async fn refresh_on_error(&self, service_request: &ServiceRequest)
When an authentication error is encountered, refresh the OIDC client info faster
Sourcepub async fn get_client(
&self,
) -> RwLockReadGuard<'_, Client<OidcAdditionalClaims, CoreAuthDisplay, CoreGenderClaim, CoreJweContentEncryptionAlgorithm, CoreJsonWebKey, CoreAuthPrompt, StandardErrorResponse<CoreErrorResponseType>, StandardTokenResponse<IdTokenFields<OidcAdditionalClaims, EmptyExtraTokenFields, CoreGenderClaim, CoreJweContentEncryptionAlgorithm, CoreJwsSigningAlgorithm>, CoreTokenType>, CoreTokenIntrospectionResponse, CoreRevocableToken, CoreRevocationErrorResponse, EndpointSet, EndpointNotSet, EndpointNotSet, EndpointNotSet, EndpointMaybeSet, EndpointMaybeSet>>
pub async fn get_client( &self, ) -> RwLockReadGuard<'_, Client<OidcAdditionalClaims, CoreAuthDisplay, CoreGenderClaim, CoreJweContentEncryptionAlgorithm, CoreJsonWebKey, CoreAuthPrompt, StandardErrorResponse<CoreErrorResponseType>, StandardTokenResponse<IdTokenFields<OidcAdditionalClaims, EmptyExtraTokenFields, CoreGenderClaim, CoreJweContentEncryptionAlgorithm, CoreJwsSigningAlgorithm>, CoreTokenType>, CoreTokenIntrospectionResponse, CoreRevocableToken, CoreRevocationErrorResponse, EndpointSet, EndpointNotSet, EndpointNotSet, EndpointNotSet, EndpointMaybeSet, EndpointMaybeSet>>
Gets a reference to the oidc client, potentially generating a new one if needed