sqlpage
0.31.0
Module render
Module Items
Structs
Enums
In crate sqlpage
sqlpage
Module
render
Structs

CsvBody
Renderer
Header
Context
Handles the first SQL statements, before the headers have been sent to
Html
Render
Context
Json
Body
Renderer
Split
Template
Renderer
Enums

AnyRender
Body
Context
Can receive rows, and write them in a given format to an
io::Write
Page
Context