Structs
Functions
- stop_
at_ first_ error - Transforms a stream of database items to stop processing after encountering the first error. The error item itself is still emitted before stopping.
- stream_
query_ results_ boxed - This function is used to create a pinned boxed stream of query results. This allows recursive calls.
- stream_
query_ results_ with_ conn